@@ -2,7 +2,6 @@
 """
 Settings overrided for test time
 """
-import django
 from django.conf import settings
 
 
@@ -24,8 +23,4 @@ MODELTRANSLATION_FALLBACK_LANGUAGES = ()
 
 ROOT_URLCONF = 'modeltranslation.tests.urls'
 
-if django.VERSION < (1, 11):
-    # TODO: Check what this was about
-    MIGRATION_MODULES = {'auth': 'modeltranslation.tests.auth_migrations'}
-else:
-    MIGRATION_MODULES = {}
+MIGRATION_MODULES = {'auth': 'modeltranslation.tests.auth_migrations'}
