@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 try:
     from django.conf.urls import include, patterns, url
-    assert (include, patterns, url)  # Workaround for pyflakes issue #13
+    # Workaround for pyflakes issue #13
+    assert (include, patterns, url)  # noqa
 except ImportError:  # Django 1.3 fallback
     from django.conf.urls.defaults import include, patterns, url  # NOQA
 from django.contrib import admin
