@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 from contextlib import contextmanager
 
-from django.utils import six
-from django.utils.encoding import force_text
+import six
+from django.utils.encoding import force_str
 from django.utils.translation import get_language as _get_language
+from django.utils.translation import get_language_info
 from django.utils.functional import lazy
 
 from modeltranslation import settings
@@ -15,6 +16,8 @@ def get_language():
     settings.LANGUAGES (Django does not seem to guarantee this for us).
     """
     lang = _get_language()
+    if lang is None:  # Django >= 1.8
+        return settings.DEFAULT_LANGUAGE
     if lang not in settings.AVAILABLE_LANGUAGES and '-' in lang:
         lang = lang.split('-')[0]
     if lang in settings.AVAILABLE_LANGUAGES:
@@ -22,19 +25,35 @@ def get_language():
     return settings.DEFAULT_LANGUAGE
 
 
+def get_language_bidi(lang):
+    """
+    Check if a language is bi-directional.
+    """
+    lang_info = get_language_info(lang)
+    return lang_info['bidi']
+
+
 def get_translation_fields(field):
     """
     Returns a list of localized fieldnames for a given field.
     """
-    return [build_localized_fieldname(field, l) for l in settings.AVAILABLE_LANGUAGES]
+    return [build_localized_fieldname(field, lang) for lang in settings.AVAILABLE_LANGUAGES]
 
 
 def build_localized_fieldname(field_name, lang):
+    if lang == 'id':
+        # The 2-letter Indonesian language code is problematic with the
+        # current naming scheme as Django foreign keys also add "id" suffix.
+        lang = 'ind'
     return str('%s_%s' % (field_name, lang.replace('-', '_')))
 
 
 def _build_localized_verbose_name(verbose_name, lang):
-    return force_text('%s [%s]') % (force_text(verbose_name), lang)
+    if lang == 'id':
+        lang = 'ind'
+    return force_str('%s [%s]') % (force_str(verbose_name), lang)
+
+
 build_localized_verbose_name = lazy(_build_localized_verbose_name, six.text_type)
 
 
@@ -47,7 +66,7 @@ def _join_css_class(bits, offset):
 def build_css_class(localized_fieldname, prefix=''):
     """
     Returns a css class based on ``localized_fieldname`` which is easily
-    splitable and capable of regionalized language codes.
+    splittable and capable of regionalized language codes.
 
     Takes an optional ``prefix`` which is prepended to the returned string.
     """
@@ -78,6 +97,10 @@ def build_css_class(localized_fieldname, prefix=''):
 
 def unique(seq):
     """
+    Returns a generator yielding unique sequence members in order
+
+    A set by itself will return unique values without any regard for order.
+
     >>> list(unique([1, 2, 3, 2, 2, 4, 1]))
     [1, 2, 3, 4]
     """
